@@ -17,12 +17,16 @@
 
 from .app import start_client as start_client
 from .app import start_keras_client as start_keras_client
+from .app import start_numpy_client as start_numpy_client
 from .client import Client as Client
 from .keras_client import KerasClient as KerasClient
+from .numpy_client import NumPyClient as NumPyClient
 
 __all__ = [
     "start_client",
     "start_keras_client",
+    "start_numpy_client",
     "Client",
     "KerasClient",
+    "NumPyClient",
 ]
