@@ -24,9 +24,11 @@ from .typing import EvaluateIns as EvaluateIns
 from .typing import EvaluateRes as EvaluateRes
 from .typing import FitIns as FitIns
 from .typing import FitRes as FitRes
+from .typing import Metrics as Metrics
 from .typing import Parameters as Parameters
 from .typing import ParametersRes as ParametersRes
 from .typing import Reconnect as Reconnect
+from .typing import Scalar as Scalar
 from .typing import Weights as Weights
 
 GRPC_MAX_MESSAGE_LENGTH: int = 536_870_912  # == 512 * 1024 * 1024
@@ -39,11 +41,13 @@ __all__ = [
     "FitIns",
     "FitRes",
     "GRPC_MAX_MESSAGE_LENGTH",
+    "Metrics",
     "ndarray_to_bytes",
     "Parameters",
     "parameters_to_weights",
     "ParametersRes",
     "Reconnect",
+    "Scalar",
     "Weights",
     "weights_to_parameters",
 ]
