@@ -16,12 +16,20 @@
 
 
 from dataclasses import dataclass
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Union
 
 import numpy as np
 
 Weights = List[np.ndarray]
 
+# The following union type contains Python types corresponding to ProtoBuf types that
+# ProtoBuf considers to be "Scalar Value Types", even though some of them arguably do
+# not conform to other definitions of what a scalar is. Source:
+# https://developers.google.com/protocol-buffers/docs/overview#scalar
+Scalar = Union[bool, bytes, float, int, str]
+
+Metrics = Dict[str, Scalar]
+
 
 @dataclass
 class Parameters:
@@ -43,7 +51,7 @@ class FitIns:
     """Fit instructions for a client."""
 
     parameters: Parameters
-    config: Dict[str, str]
+    config: Dict[str, Scalar]
 
 
 @dataclass
@@ -51,10 +59,10 @@ class FitRes:
     """Fit response from a client."""
 
     parameters: Parameters
-    # config: Dict[str, str]
     num_examples: int
-    num_examples_ceil: int
-    fit_duration: float
+    num_examples_ceil: Optional[int] = None  # Deprecated
+    fit_duration: Optional[float] = None  # Deprecated
+    metrics: Optional[Metrics] = None
 
 
 @dataclass
@@ -62,16 +70,17 @@ class EvaluateIns:
     """Evaluate instructions for a client."""
 
     parameters: Parameters
-    config: Dict[str, str]
+    config: Dict[str, Scalar]
 
 
 @dataclass
 class EvaluateRes:
     """Evaluate response from a client."""
 
-    num_examples: int
     loss: float
-    accuracy: float
+    num_examples: int
+    accuracy: Optional[float] = None  # Deprecated
+    metrics: Optional[Metrics] = None
 
 
 @dataclass
