@@ -18,6 +18,7 @@ Paper: https://arxiv.org/abs/1602.05629
 """
 
 
+from logging import WARNING
 from typing import Callable, Dict, List, Optional, Tuple
 
 from flwr.common import (
@@ -25,17 +26,48 @@ from flwr.common import (
     EvaluateRes,
     FitIns,
     FitRes,
+    Parameters,
     Scalar,
     Weights,
     parameters_to_weights,
     weights_to_parameters,
 )
+from flwr.common.logger import log
 from flwr.server.client_manager import ClientManager
 from flwr.server.client_proxy import ClientProxy
 
 from .aggregate import aggregate, weighted_loss_avg
 from .strategy import Strategy
 
+DEPRECATION_WARNING = """
+DEPRECATION WARNING: deprecated `eval_fn` return format
+
+    loss, accuracy
+
+move to
+
+    loss, {"accuracy": accuracy}
+
+instead. Note that compatibility with the deprecated return format will be
+removed in a future release.
+"""
+
+DEPRECATION_WARNING_INITIAL_PARAMETERS = """
+DEPRECATION WARNING: deprecated initial parameter type
+
+    flwr.common.Weights (i.e., List[np.ndarray])
+
+will be removed in a future update, move to
+
+    flwr.common.Parameters
+
+instead. Use
+
+    parameters = flwr.common.weights_to_parameters(weights)
+
+to easily transform `Weights` to `Parameters`.
+"""
+
 
 class FedAvg(Strategy):
     """Configurable FedAvg strategy implementation."""
@@ -48,11 +80,13 @@ class FedAvg(Strategy):
         min_fit_clients: int = 2,
         min_eval_clients: int = 2,
         min_available_clients: int = 2,
-        eval_fn: Optional[Callable[[Weights], Optional[Tuple[float, float]]]] = None,
+        eval_fn: Optional[
+            Callable[[Weights], Optional[Tuple[float, Dict[str, Scalar]]]]
+        ] = None,
         on_fit_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
         on_evaluate_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
         accept_failures: bool = True,
-        initial_parameters: Optional[Weights] = None,
+        initial_parameters: Optional[Parameters] = None,
     ) -> None:
         """Federated Averaging strategy.
 
@@ -77,7 +111,7 @@ class FedAvg(Strategy):
                 Function used to configure validation. Defaults to None.
             accept_failures (bool, optional): Whether or not accept rounds
                 containing failures. Defaults to True.
-            initial_parameters (Weights, optional): Initial global model parameters.
+            initial_parameters (Parameters, optional): Initial global model parameters.
         """
         super().__init__()
         self.min_fit_clients = min_fit_clients
@@ -106,25 +140,40 @@ class FedAvg(Strategy):
         num_clients = int(num_available_clients * self.fraction_eval)
         return max(num_clients, self.min_eval_clients), self.min_available_clients
 
-    def initialize_parameters(self, client_manager: ClientManager) -> Optional[Weights]:
+    def initialize_parameters(
+        self, client_manager: ClientManager
+    ) -> Optional[Parameters]:
         """Initialize global model parameters."""
         initial_parameters = self.initial_parameters
         self.initial_parameters = None  # Don't keep initial parameters in memory
+        if isinstance(initial_parameters, list):
+            log(WARNING, DEPRECATION_WARNING_INITIAL_PARAMETERS)
+            initial_parameters = weights_to_parameters(weights=initial_parameters)
         return initial_parameters
 
-    def evaluate(self, weights: Weights) -> Optional[Tuple[float, float]]:
-        """Evaluate model weights using an evaluation function (if
-        provided)."""
+    def evaluate(
+        self, parameters: Parameters
+    ) -> Optional[Tuple[float, Dict[str, Scalar]]]:
+        """Evaluate model parameters using an evaluation function."""
         if self.eval_fn is None:
             # No evaluation function provided
             return None
-        return self.eval_fn(weights)
+        weights = parameters_to_weights(parameters)
+        eval_res = self.eval_fn(weights)
+        if eval_res is None:
+            return None
+        loss, other = eval_res
+        if isinstance(other, float):
+            print(DEPRECATION_WARNING)
+            metrics = {"accuracy": other}
+        else:
+            metrics = other
+        return loss, metrics
 
     def configure_fit(
-        self, rnd: int, weights: Weights, client_manager: ClientManager
+        self, rnd: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, FitIns]]:
         """Configure the next round of training."""
-        parameters = weights_to_parameters(weights)
         config = {}
         if self.on_fit_config_fn is not None:
             # Custom fit config function provided
@@ -143,7 +192,7 @@ class FedAvg(Strategy):
         return [(client, fit_ins) for client in clients]
 
     def configure_evaluate(
-        self, rnd: int, weights: Weights, client_manager: ClientManager
+        self, rnd: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, EvaluateIns]]:
         """Configure the next round of evaluation."""
         # Do not configure federated evaluation if a centralized evaluation
@@ -152,7 +201,6 @@ class FedAvg(Strategy):
             return []
 
         # Parameters and config
-        parameters = weights_to_parameters(weights)
         config = {}
         if self.on_evaluate_config_fn is not None:
             # Custom evaluation config function provided
@@ -178,35 +226,40 @@ class FedAvg(Strategy):
         rnd: int,
         results: List[Tuple[ClientProxy, FitRes]],
         failures: List[BaseException],
-    ) -> Optional[Weights]:
+    ) -> Tuple[Optional[Parameters], Dict[str, Scalar]]:
         """Aggregate fit results using weighted average."""
         if not results:
-            return None
+            return None, {}
         # Do not aggregate if there are failures and failures are not accepted
         if not self.accept_failures and failures:
-            return None
+            return None, {}
         # Convert results
         weights_results = [
             (parameters_to_weights(fit_res.parameters), fit_res.num_examples)
             for client, fit_res in results
         ]
-        return aggregate(weights_results)
+        return weights_to_parameters(aggregate(weights_results)), {}
 
     def aggregate_evaluate(
         self,
         rnd: int,
         results: List[Tuple[ClientProxy, EvaluateRes]],
         failures: List[BaseException],
-    ) -> Optional[float]:
+    ) -> Tuple[Optional[float], Dict[str, Scalar]]:
         """Aggregate evaluation losses using weighted average."""
         if not results:
-            return None
+            return None, {}
         # Do not aggregate if there are failures and failures are not accepted
         if not self.accept_failures and failures:
-            return None
-        return weighted_loss_avg(
+            return None, {}
+        loss_aggregated = weighted_loss_avg(
             [
-                (evaluate_res.num_examples, evaluate_res.loss, evaluate_res.accuracy)
+                (
+                    evaluate_res.num_examples,
+                    evaluate_res.loss,
+                    evaluate_res.accuracy,
+                )
                 for _, evaluate_res in results
             ]
         )
+        return loss_aggregated, {}
