@@ -16,9 +16,17 @@
 
 
 from abc import ABC, abstractmethod
-from typing import List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple, Union
 
-from flwr.common import EvaluateIns, EvaluateRes, FitIns, FitRes, Weights
+from flwr.common import (
+    EvaluateIns,
+    EvaluateRes,
+    FitIns,
+    FitRes,
+    Parameters,
+    Scalar,
+    Weights,
+)
 from flwr.server.client_manager import ClientManager
 from flwr.server.client_proxy import ClientProxy
 
@@ -27,35 +35,44 @@ class Strategy(ABC):
     """Abstract base class for server strategy implementations."""
 
     @abstractmethod
-    def initialize_parameters(self, client_manager: ClientManager) -> Optional[Weights]:
+    def initialize_parameters(
+        self, client_manager: ClientManager
+    ) -> Optional[Parameters]:
         """Initialize the (global) model parameters.
 
-        Arguments:
+        Parameters
+        ----------
             client_manager: ClientManager. The client manager which holds all currently
                 connected clients.
 
-        Returns:
-            Optional `flwr.common.Weights`. If parameters are returned, then the server
-            will treat these as the initial global model parameters.
+        Returns
+        -------
+        parameters: Parameters (optional)
+            If parameters are returned, then the server will treat these as the
+            initial global model parameters.
         """
 
     @abstractmethod
     def configure_fit(
-        self, rnd: int, weights: Weights, client_manager: ClientManager
+        self, rnd: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, FitIns]]:
         """Configure the next round of training.
 
-        Arguments:
-            rnd: Integer. The current round of federated learning.
-            weights: Weights. The current (global) model weights.
-            client_manager: ClientManager. The client manager which holds all currently
-                connected clients.
+        Parameters
+        ----------
+        rnd : int
+            The current round of federated learning.
+        parameters : Parameters
+            The current (global) model parameters.
+        client_manager : ClientManager
+            The client manager which holds all currently connected clients.
 
-        Returns:
-            A list of tuples. Each tuple in the list identifies a `ClientProxy` and the
-            `FitIns` for this particular `ClientProxy`. If a particular `ClientProxy`
-            is not included in this list, it means that this `ClientProxy`
-            will not participate in the next round of federated learning.
+        Returns
+        -------
+        A list of tuples. Each tuple in the list identifies a `ClientProxy` and the
+        `FitIns` for this particular `ClientProxy`. If a particular `ClientProxy`
+        is not included in this list, it means that this `ClientProxy`
+        will not participate in the next round of federated learning.
         """
 
     @abstractmethod
@@ -64,40 +81,49 @@ class Strategy(ABC):
         rnd: int,
         results: List[Tuple[ClientProxy, FitRes]],
         failures: List[BaseException],
-    ) -> Optional[Weights]:
+    ) -> Union[
+        Tuple[Optional[Parameters], Dict[str, Scalar]],
+        Optional[Weights],  # Deprecated
+    ]:
         """Aggregate training results.
 
-        Arguments:
-            rnd: int. The current round of federated learning.
-            results: List[Tuple[ClientProxy, FitRes]]. Successful updates from the
-                previously selected and configured clients. Each pair of
-                `(ClientProxy, FitRes` constitutes a successful update from one of the
-                previously selected clients. Not that not all previously selected
-                clients are necessarily included in this list: a client might drop out
-                and not submit a result. For each client that did not submit an update,
-                there should be an `Exception` in `failures`.
-            failures: List[BaseException]. Exceptions that occurred while the server
-                was waiting for client updates.
+        Parameters
+        ----------
+        rnd : int
+            The current round of federated learning.
+        results : List[Tuple[ClientProxy, FitRes]]
+            Successful updates from the previously selected and configured
+            clients. Each pair of `(ClientProxy, FitRes)` constitutes a
+            successful update from one of the previously selected clients. Not
+            that not all previously selected clients are necessarily included in
+            this list: a client might drop out and not submit a result. For each
+            client that did not submit an update, there should be an `Exception`
+            in `failures`.
+        failures : List[BaseException]
+            Exceptions that occurred while the server was waiting for client
+            updates.
 
-        Returns:
-            Optional `flwr.common.Weights`. If weights are returned, then the server
-            will treat these as the new global model weights (i.e., it will replace the
-            previous weights with the ones returned from this method). If `None` is
-            returned (e.g., because there were only failures and no viable results)
-            then the server will no update the previous model weights, the updates
-            received in this round are discarded, and the global model weights remain
-            the same.
+        Returns
+        -------
+        parameters: Parameters (optional)
+            If parameters are returned, then the server will treat these as the
+            new global model parameters (i.e., it will replace the previous
+            parameters with the ones returned from this method). If `None` is
+            returned (e.g., because there were only failures and no viable
+            results) then the server will no update the previous model
+            parameters, the updates received in this round are discarded, and
+            the global model parameters remain the same.
         """
 
     @abstractmethod
     def configure_evaluate(
-        self, rnd: int, weights: Weights, client_manager: ClientManager
+        self, rnd: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, EvaluateIns]]:
         """Configure the next round of evaluation.
 
         Arguments:
             rnd: Integer. The current round of federated learning.
-            weights: Weights. The current (global) model weights.
+            parameters: Parameters. The current (global) model parameters.
             client_manager: ClientManager. The client manager which holds all currently
                 connected clients.
 
@@ -115,7 +141,10 @@ class Strategy(ABC):
         rnd: int,
         results: List[Tuple[ClientProxy, EvaluateRes]],
         failures: List[BaseException],
-    ) -> Optional[float]:
+    ) -> Union[
+        Tuple[Optional[float], Dict[str, Scalar]],
+        Optional[float],  # Deprecated
+    ]:
         """Aggregate evaluation results.
 
         Arguments:
@@ -136,15 +165,18 @@ class Strategy(ABC):
         """
 
     @abstractmethod
-    def evaluate(self, weights: Weights) -> Optional[Tuple[float, float]]:
-        """Evaluate the current model weights.
+    def evaluate(
+        self, parameters: Parameters
+    ) -> Optional[Tuple[float, Dict[str, Scalar]]]:
+        """Evaluate the current model parameters.
 
         This function can be used to perform centralized (i.e., server-side) evaluation
-        of model weights.
+        of model parameters.
 
         Arguments:
-            weights: Weights. The current (global) model weights.
+            parameters: Parameters. The current (global) model parameters.
 
         Returns:
-            The evaluation result, usually a Tuple containing loss and accuracy.
+            The evaluation result, usually a Tuple containing loss and a
+            dictionary containing task-specific metrics (e.g., accuracy).
         """
